/*
 * mailodymailviewer.cpp
 *
 * Copyright (C) 2008 Omat Holding B.V. <info@omat.nl>
 */
#include "mailodymailviewer.h"
#include "mailodymailviewerview.h"

#include <QtGui/QDropEvent>
#include <QtGui/QPainter>
#include <QtGui/QPrinter>
#include <QtCore/QCoreApplication>

#include <kconfigdialog.h>
#include <kstatusbar.h>

#include <kaction.h>
#include <kactioncollection.h>
#include <kstandardaction.h>

#include <kio/job.h>
#include <kio/netaccess.h>

#include <kmime/kmime_message.h>

#include <KDE/KLocale>

MailodyMailViewer::MailodyMailViewer()
        : KXmlGuiWindow(),
        m_view( new MailodyMailViewerView( this ) ),
        m_printer( 0 )
{
    // accept dnd
    setAcceptDrops( true );

    // tell the KXmlGuiWindow that this is indeed the main widget
    setCentralWidget( m_view );

    // then, setup our actions
    setupActions();

    // add a status bar
    statusBar()->show();

    // a call to KXmlGuiWindow::setupGUI() populates the GUI
    // with actions, using KXMLGUI.
    // It also applies the saved mainwindow settings, if any, and ask the
    // mainwindow to automatically save settings if changed: window size,
    // toolbar position, icon size, etc.
    setupGUI();
}

MailodyMailViewer::~MailodyMailViewer()
{
}

void MailodyMailViewer::setupActions()
{
    KStandardAction::openNew( this, SLOT( fileNew() ), actionCollection() );
    KStandardAction::quit( qApp, SLOT( closeAllWindows() ), actionCollection() );
}

void MailodyMailViewer::fileNew()
{
    // this slot is called whenever the File->New menu is selected,
    // the New shortcut is pressed (usually CTRL+N) or the New toolbar
    // button is clicked

    // create a new window
    ( new MailodyMailViewer )->show();
}

void MailodyMailViewer::openFile( const QString& filename )
{
    KUrl url( filename );
    KIO::Job *job = KIO::get( url );
    QByteArray data;
    if ( KIO::NetAccess::synchronousRun( job, 0, &data ) ) {
        //kDebug() << data;
    }

    KMime::Message* msg = new KMime::Message;
    msg->setContent( KMime::CRLFtoLF( data ) );
    msg->parse();

    Mailody::MessageData* msgdata = new Mailody::MessageData( m_view );
    msgdata->setMsg( msg );

    m_view->setMsg( msgdata );

    kDebug() << msg->head();
}

#include "mailodymailviewer.moc"
