/* This file is part of the KDE project
   Copyright (C) 2006-2007 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "addresslineedit.h"

#include <QMouseEvent>
#include <QKeyEvent>
#include <QTimer>
#include <QPoint>
#include <QWhatsThis>

#include <kpimutils/email.h>

#include <KColorScheme>

using namespace Mailody;

//------------- AddressLineEdit -------------------//
AddressLineEdit::AddressLineEdit( QWidget *parent )
        : KLineEdit( parent )
        , m_helpText( false )
{
    m_timer = new QTimer( this );
    m_timer->setSingleShot( true );
    connect( m_timer, SIGNAL( timeout() ), SLOT( slotShowHelp() ) );
}

void AddressLineEdit::keyPressEvent( QKeyEvent *e )
{
    m_timer->stop();
    if ( m_helpText && !( e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter ) ) {
        clear();
        setHelp( false );
    } else if ( m_helpText && ( e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter ) ) {
        emit shiftAddress();
    } else if ( !m_helpText && ( e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter ) ) {
        emit addAddress( text() );
    } else {
        validate();
    }
    KLineEdit::keyPressEvent( e );
}

void AddressLineEdit::mousePressEvent( QMouseEvent *e )
{
    if ( help() ) {
        clear();
        setHelp( false );
        KLineEdit::mousePressEvent( e );
    }
}

void AddressLineEdit::validate()
{
    const KPIMUtils::EmailParseResult result = KPIMUtils::isValidAddress( text() );
    emit containsValidAddress( result == KPIMUtils::AddressOk );

    if ( !help() )
        m_timer->start( 3000 );
}

void AddressLineEdit::slotShowHelp()
{
    const KPIMUtils::EmailParseResult result = KPIMUtils::isValidAddress( text() );
    if ( result != KPIMUtils::AddressOk && !help() ) {
        const QString showHelp = emailParseResultToString( result );

        /* seems fragile to me. I don't seem to understand the positioning of this widget */
        const QPoint globalPos( mapToGlobal( mapToParent( pos() ) ) );
        const QPoint pos( globalPos.x(), globalPos.y()+5 );
        QWhatsThis::showText( pos, showHelp );
    }
}

void AddressLineEdit::slotSetAddress( const QString &text )
{
    setText( text );
    validate();
}

void AddressLineEdit::setHelp( bool i )
{
    m_helpText = i;
    QPalette p;
    if ( i ) {
        p.setColor( QPalette::Normal, QPalette::Text, QColor( 160,160,160 ) );
        setCursorPosition( 0 );
    } else {
        p.setColor( QPalette::Normal, QPalette::Text,
                    KColorScheme( QPalette::Active, KColorScheme::View ).foreground().color() );
    }
    setPalette( p );
}

#include "addresslineedit.moc"
