/*
   Copyright (C) 2006-2009 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef ADDRESSLINEEDIT_H
#define ADDRESSLINEEDIT_H

#include <klineedit.h>
#include <kcompletionbox.h>

class QMouseEvent;
class QKeyEvent;

namespace Mailody
{

/**
 * @class AddressLineEdit
 * This class provides Composers KLineEdit with auto completion
 * @author Tom Albers <tomalbers@kde.nl>
 */
class AddressLineEdit : public KLineEdit
{
    Q_OBJECT

public:
    /**
     * Constructor
     */
    explicit AddressLineEdit( QWidget* );

    /**
     * indicate if the text in the edit field is a help text.
     * which disabled the button.
     * @param i true if the text is a help text.
     */
    void setHelp( bool i );

    /**
     * returns true if the current text is a help text
     */
    bool help() const {
        return m_helpText;
    };

protected:
    /**
     * reimplemented to be able to remove the help text
     */
    void keyPressEvent( QKeyEvent* );
    /**
     * reimplemented to be able to remove the help text
     */
    void mousePressEvent( QMouseEvent* );

// @cond private
private:
    bool        m_helpText;
    QTimer      *m_timer;

private slots:
    void slotSetAddress( const QString& );
    void validate();
    void slotShowHelp();
// @endcond

signals:
    /**
     * Will be emitted when the address needs to shift from to->cc, cc->bcc
     */
    void shiftAddress();

    /**
     * Will be emitted when the @p address needs to be added to the
     * addressees.
     * @param address address to add.
     */
    void addAddress( const QString &address );

    /**
     * Will emit a signal when the edit field contains a valid / invalid
     * address.
     */
    void containsValidAddress( bool );
};

}

#endif
