/*
   Copyright (C) 2008 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef ATTACHMENTWIDGET_H
#define ATTACHMENTWIDGET_H

#include <QWidget>
#include <QListView>

class KUrl;
class QDropEvent;
class QStandardItemModel;
class QStandardItem;

namespace Mailody
{

/**
 * @class AttachmentWidget
 * This widget provides an overview of the attachments and interacts
 * with the user, so he can delete them, view them or whatever.
 * Also handles file drops.
 * @author Tom Albers <tomalbers@kde.nl>
 */
class AttachmentWidget : public QWidget
{
    Q_OBJECT

public:
    /**
     * Constructor
     * @param parent the parent widget
     */
    explicit AttachmentWidget( QWidget *parent );

    /**
     * Adds an attachment, the mime type icon will be shown.
     * @param attachment the KUrl to the attachment
     * @param name the user visible name for this attachment. Usable in situation
     * where the @p attachment is a temporary file for example.
     */
    void addAttachment( const KUrl &attachment , const QString& name=QString() );

    /**
     * returns a list of attachments. The QHash consists of the KUrl of the attachment
     * and the user visible name.
     */
    QHash<KUrl, QString> attachments() const;

protected:
    /**
     * Reimplemented to signal the addition of an attachment.
     */
    void dropEvent( QDropEvent* );

// @cond private
private slots:
    void slotOpen( const QModelIndexList & );
    void slotRemove( const QModelIndexList & );

private:
    QStandardItemModel *m_model;
    QHash<QStandardItem*, KUrl> allItems;
// @endcond

signals:
    /**
     * Signal is emitted when the user has deleted all attachments. Use this to
     * delete or hide this widget.
     */
    void noAttachmentsLeft();
};

/**
 * @class AttachmentView
 * This class is the view part of the AttachmentWidget widget and should not be
 * used directly.
 * @author T.M. Albers
 */
class AttachmentView : public QListView
{
    Q_OBJECT

public:
    /** Constructor */
    AttachmentView( QWidget* );

protected:
    /** Reimplemented */
    virtual void contextMenuEvent( QContextMenuEvent* );
    /** Reimplemented */
    virtual void mouseDoubleClickEvent( QMouseEvent* );

signals:
    /** Remove these items */
    void removeItems( const QModelIndexList& );
    /** Open these items */
    void openItems( const QModelIndexList& );
};
}

#endif
