/* This file is part of the KDE project
   Copyright (C) 2006-2007 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "composertextedit.h"

#include <QDropEvent>
#include <krichtextwidget.h>
#include <kpimtextedit/emailquotehighlighter.h>

using namespace Mailody;

ComposerTextEdit::ComposerTextEdit( QWidget* parent )
        : KPIMTextEdit::TextEdit( parent )
{
    setAcceptDrops( true );
    setCheckSpellingEnabled( true );

    m_qh = new KPIMTextEdit::EMailQuoteHighlighter( this );
    m_qh->toggleSpellHighlighting( true );
    m_qh->setQuoteColor( QColor() /* will be ignored according to the api */,
                         QColor( Qt::darkGreen ),
                         QColor( Qt::darkRed ),
                         QColor( Qt::blue ) );
    connect( this, SIGNAL( checkSpellingChanged( bool ) ),
             SLOT( slotCheckSpellingChanged( bool ) ) );
}

void ComposerTextEdit::dropEvent( QDropEvent *e )
{
    const KUrl::List uriList = KUrl::List::fromMimeData( e->mimeData() );
    if ( !uriList.isEmpty() ) {
        for ( KUrl::List::ConstIterator it = uriList.begin();
                it != uriList.end(); ++it )
            emit addAttachment( *it );
    }
}

void ComposerTextEdit::slotCheckSpellingChanged( bool val )
{
    m_qh->toggleSpellHighlighting( val );
}

#include "composertextedit.moc"
