/* This file is part of the KDE project

   Copyright (C) 2006-2007 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef COMPOSERTEXTEDIT_H
#define COMPOSERTEXTEDIT_H

#include <KPIMTextEdit/TextEdit>
#include <KUrl>

class QDropEvent;

namespace Mailody
{

/**
 * @class ComposerTextEdit
 * This class is a KRichTextWidget, which is subclassed to emit a signal
 * when a file is dropped on it.
 * @author Tom Albers <tomalbers@kde.nl>
 */
class ComposerTextEdit : public KPIMTextEdit::TextEdit
{
    Q_OBJECT

public:
    /**
     * Constructor
     * @param parent the parent widget
     */
    explicit ComposerTextEdit( QWidget* parent );

protected:
    /**
     * Reimplemented to signal the addition of an attachment.
     */
    void dropEvent( QDropEvent* );

signals:
    /**
     * Emitted when a file is dropped on the widget. Will probably disappear as soon
     * as the KRichTextWidget supports images.
     */
    void addAttachment( const KUrl& );

private slots:
    void slotCheckSpellingChanged( bool );

private:
    KPIMTextEdit::EMailQuoteHighlighter* m_qh;
};

}

#endif // COMPOSERTEXTEDIT
