/*
   Copyright (C) 2009 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "contactcreation.h"

#include <QTimer>

#include <akonadi/collection.h>
#include <akonadi/contact/contacteditordialog.h>
#include <akonadi/contact/contacteditor.h>
#include <akonadi/item.h>
#include <akonadi/itemcreatejob.h>
#include <akonadi/itemdeletejob.h>
#include <kabc/addressee.h>
#include <kpimutils/email.h>

using namespace Mailody;

ContactCreation::ContactCreation( QWidget* parent, const QString& address,
                                  Akonadi::Collection collection )
        : QObject( parent )
{
    QString email, name;
    bool ok = KPIMUtils::extractEmailAddressAndName( address, email, name );
    if ( !ok ) {
        kDebug() << "splitting name and mail failed for:" << address;
        return;
    }
    kDebug() << name << email;

    KABC::Addressee addressee;
    addressee.setNameFromString( name );
    addressee.setEmails( QStringList( email ) );

    Akonadi::ContactEditorDialog* dlg =
        new Akonadi::ContactEditorDialog( Akonadi::ContactEditorDialog::CreateMode,
                                          parent );
    dlg->setDefaultAddressBook( collection );
    dlg->editor()->setContactTemplate( addressee );
    dlg->show();
}
