/*
   Copyright (C) 2009 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

//Own
#include "contacttooltipproxymodel.h"

//KDE
#include <akonadi/contact/contactviewer.h>
#include <akonadi/contact/contactviewerdialog.h>
#include <akonadi/contact/contactgroupviewer.h>
#include <akonadi/contact/contactgroupviewerdialog.h>
#include <akonadi/entitytreemodel.h>

using namespace Mailody;
using namespace Akonadi;

ContactToolTipProxyModel::ContactToolTipProxyModel( QObject *parent )
        : QSortFilterProxyModel( parent )
{
    m_contactViewer = new Akonadi::ContactViewerDialog( 0 );
    connect( m_contactViewer->viewer(),
             SIGNAL( emailClicked( const QString&, const QString& ) ),
             SLOT( slotMailClicked( const QString&, const QString& ) ) );
    m_contactViewer->hide();

    m_contactGroupViewer = new Akonadi::ContactGroupViewerDialog( 0 );
    connect( m_contactGroupViewer->viewer(),
             SIGNAL( emailClicked( const QString&, const QString& ) ),
             SLOT( slotMailClicked( const QString&, const QString& ) ) );
    m_contactGroupViewer->hide();
}

ContactToolTipProxyModel::~ContactToolTipProxyModel()
{
    delete m_contactViewer;
    delete m_contactGroupViewer;
}

QVariant ContactToolTipProxyModel::data( const QModelIndex & index, int role ) const
{
    if ( role != Qt::ToolTipRole )
        return QSortFilterProxyModel::data( index, role );

    const QModelIndex sourceIndex = mapToSource( index );
    const Akonadi::Item item = sourceModel()->data( sourceIndex, EntityTreeModel::ItemRole ).value<Item>();

    if ( !item.isValid() ) {
        m_contactViewer->setContact( Akonadi::Item() );
        m_contactViewer->hide();
        return QVariant();
    }

    if ( item == m_contactViewer->contact() )
        return QVariant();

    if ( item.mimeType() == "text/directory" ) {
        m_contactViewer->setContact( item );
        m_contactViewer->move( QCursor::pos() );
        m_contactViewer->resize( QSize( 400, 400 ) );
        m_contactViewer->show();
    } else if ( item.mimeType() == "application/x-vnd.kde.contactgroup" ) {
        m_contactGroupViewer->setContactGroup( item );
        m_contactGroupViewer->move( QCursor::pos() );
        m_contactGroupViewer->resize( QSize( 400, 400 ) );
        m_contactGroupViewer->show();
    }

    return QVariant();
}

void ContactToolTipProxyModel::slotMailClicked( const QString& name, const QString& address )
{
    KMime::Types::Mailbox mb;
    mb.setAddress( address.toLocal8Bit() );
    mb.setName( name.toLocal8Bit() );
    emit mailClicked( mb.prettyAddress() );
}

#include "contacttooltipproxymodel.moc"
