/*
   Copyright (C) 2009 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

//Own
#include "contacttreemodel.h"

//KDE
#include <klocale.h>
#include <kabc/addressee.h>
#include <kabc/contactgroup.h>
#include <kmime/kmime_header_parsing.h>
#include <akonadi/changerecorder.h>

using namespace Mailody;

ContactTreeModel::ContactTreeModel( Akonadi::ChangeRecorder *monitor, QObject *parent )
        : Akonadi::EntityTreeModel( monitor, parent )
{
}

QVariant ContactTreeModel::data( const QModelIndex &index, int role ) const
{
    if ( role != Qt::DisplayRole && role != AddressRole )
        return Akonadi::EntityTreeModel::data( index, role );

    const Akonadi::Item item = index.data( Akonadi::EntityTreeModel::ItemRole ).value<Akonadi::Item>();
    if ( !item.isValid() )
        return Akonadi::EntityTreeModel::data( index, role );

    if ( item.mimeType() == "text/directory" ) {
        if ( !item.hasPayload<KABC::Addressee>() ) {
            kDebug() << "No payload?";
            return Akonadi::EntityTreeModel::data( index, role );
        }

        const KABC::Addressee addr = item.payload<KABC::Addressee>();

        if ( role == Qt::DisplayRole ) {
            return i18nc( "fullname (emailaddress)","%1 (%2)",
                          addr.formattedName(), addr.preferredEmail() );
        } else if ( role == AddressRole ) {
            KMime::Types::Mailbox mb;
            mb.setAddress( addr.preferredEmail().toLocal8Bit() );
            mb.setName( addr.formattedName().toLocal8Bit() );
            kDebug() << mb.address();
            return mb.prettyAddress();
        }
    } else if ( item.mimeType() == "application/x-vnd.kde.contactgroup" ) {
        if ( !item.hasPayload<KABC::ContactGroup>() ) {
            kDebug() << "No payload?";
            return Akonadi::EntityTreeModel::data( index, role );
        }

        const KABC::ContactGroup group = item.payload<KABC::ContactGroup>();
        return group.name();
    }

    return QVariant();
}

Qt::ItemFlags ContactTreeModel::flags( const QModelIndex& ) const
{
    return Qt::ItemIsEnabled;
}

