/*
   Copyright (C) 2009 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "flagmodifyjob.h"

#include <QStringList>

FlagModifyJob::FlagModifyJob( const Akonadi::Item &item,
                              const QString& flag,
                              QObject * parent )
        : Akonadi::ItemModifyJob( setFlag( item, flag ),
                                  parent )
{
}

FlagModifyJob::~FlagModifyJob()
{
}

Akonadi::Item FlagModifyJob::setFlag( const Akonadi::Item& item,
                                      const QString& tag )
{
    if ( tag.startsWith( QLatin1String( "$label" ) ) )
        return setExclusiveFlag( item, tag );
    else {
        Akonadi::Item newItem( item );
        newItem.setFlag( tag.toLatin1() );
        return newItem;
    }
}

Akonadi::Item FlagModifyJob::setExclusiveFlag( const Akonadi::Item& item,
        const QString& tag )
{
    kDebug() << item.id() << tag;
    QStringList addList, removeList;
    for ( int i = 1; i < 6; ++i ) {
        const QString& label = "$label" + QString::number( i );
        if ( tag == label && !item.hasFlag( label.toLatin1() ) ) {
            addList.append( label );
        } else if ( tag != label && item.hasFlag( label.toLatin1() ) ) {
            removeList.append( label );
        }
    }

    if ( addList.isEmpty() && removeList.isEmpty() )
        return item;

    Akonadi::Item newItem( item );
    foreach( const QString& listItem, removeList )
    newItem.clearFlag( listItem.toLatin1() );
    foreach( const QString& listItem, addList )
    newItem.setFlag( listItem.toLatin1() );

    return newItem;
}
