/* This file is part of the KDE project

   Copyright (C) 2006-2007 Omat Holding B.V. <info@omat.nl>
   Copyright (C) 2007 Frode M. Døving <frode@lnix.net>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/


#ifndef GLOBAL_H
#define GLOBAL_H

#include <QObject>
#include <kabc/stdaddressbook.h>
#include <sys/time.h>

#include <kpimidentities/identitymanager.h>

namespace Mailody
{

static const char s_usehtml[] = "useHTMLPart";
static const char s_preferhtml[] = "preferComposeHTML";
static const char s_usesig[] = "useSig";
static const char s_signature[] = "signature";
static const char s_sigpos[] = "SigPos";

namespace Global
{
/**
 * Will return the identites cached and not updated
 * during lifetime unless @p force is true
 * @param force refresh
 */
bool myEmail( const QString& email, bool refresh=false );

/**
 * Returns the identity which has @p email as address.
 */
const KPIMIdentities::Identity getIdentityForEmail(
    const QString& email );

/**
 * Will print the ms between @p tv1 and @p tv2 with the
 * comment @p text. Use it like:
 *
 *   #include <sys/time.h>
 *
 *   struct timeval tv1, tv2;
 *   gettimeofday(&tv1, 0);
 *   .. expensive stuff ...
 *   gettimeofday(&tv2, 0);
 *   Global::timing("expensive stuff", tv1, tv2);
 */
void timing( const QString& text, struct timeval tv1,
             struct timeval tv2 );

/**
 * this will color each paragraph with a color depending on the
 * quotatation level.
 */
QString highlightText( const QString& text );

/** this will color the text with a color depending on the quotation
 * level
 */
QString highlightParagraph( const QString& text );

/**
 * Returns the identitymanager.
 */
KPIMIdentities::IdentityManager * identityManager();

/**
  * Alters @p text so it contains an extra > in front of each line;
  */
QString quote( const QString &text, bool stripSig=true );
}

}

#endif
