/* This file is part of the KDE project

   Copyright (C) 2007-2008 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef HEADERPROXY_H
#define HEADERPROXY_H

#include <QHash>
#include <QSortFilterProxyModel>
#include <QStringList>

#include <akonadi/item.h>

namespace Mailody
{

/**
 * @class HeaderProxy
 * @brief The filter class for the headers.
 *
 * This class is a QSortFilterProxyModel and does several things:
 * - deal with the quick search bar
 * - merging sender and recipient from the model
 * - hide deleted messages if ordered to.
 * @author Tom Albers <tomalbers@kde.nl>
 */
class HeaderProxy : public QSortFilterProxyModel
{
    Q_OBJECT

public:
    /**
     * Constructor
     * @param parent the parent widget.
     */
    HeaderProxy( QObject * parent );

    /**
     * Call this to indicate if deleted messages should be shown or not.
     * It will update the view.
     * @param hide set to true to hide deleted messages.
     */
    void setHideDeleted( bool hide );

    /**
     * Call this to indicate if messages should be sorted on the
     * youngest child or not.
     * It will update the view.
     * @param sort set to true to sort on the youngest child.
     */
    void setSortOnChild( bool sort );

    /**
     * Call this to set a certain filter. This function also filters messages
     * matching a tag with that name.
     */
    void setFilter( const QString& );

protected:
    /** Reimplemented to merge sender / recipient */
    virtual QVariant data( const QModelIndex&, int = Qt::DisplayRole ) const;

    /**
     * Reimplemented to filter out deleted records if ordered, and to filter rows
     * based on the quick search bar.
     */
    virtual bool filterAcceptsRow( int, const QModelIndex& ) const;

    /**
     * Reimplemented to filter out the useless size column for now and to filter
     * out the recipient column, which is merged in the data() call.
     */
    virtual bool filterAcceptsColumn( int, const QModelIndex& ) const;

// @cond private
private:
    bool m_hideDeleted;
    Akonadi::Item::List m_nepomukMessages;
// @endcond
};

}

#endif
