/* This file is part of the KDE project

   Copyright (C) 2007 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef HEADERVIEW_H
#define HEADERVIEW_H

#include "messagedata.h"
#include "messagebodywidget.h" // enum

#include <QAbstractItemModel>
#include <QModelIndex>
#include <QVariant>
#include <QMouseEvent>

#include <akonadi/item.h>
#include <akonadi/entitytreeview.h>

namespace Mailody
{

/**
 * @class HeaderView
 * This is the view part of the headers. Basically a QTreeView.
 * It includes some helpers so the column sizes can be saved and
 * restored easily. And emit some additional signals.
 * This class should not be used directly, but use the HeaderWidget
 * @private
 * @author Tom Albers <tomalbers@kde.nl>
 */
class HeaderView : public Akonadi::EntityTreeView
{
    Q_OBJECT

public:
    /**
     * Constructor
     * @param parent the parent widget
     */
    HeaderView( QWidget * parent = 0 );

    /** Returns a list of column sizes so you can easily store them */
    QList<int> columnSizes();

    /** Sets the column sizes based on the passed list */
    void setColumnSizes( QList<int> );

    /**
     * call this to expand @p index
     * @param index Index to expand.
     */
    void openItem( const QModelIndex & index );

    /**
     * activates next new message and returned if it worked out.
     */
    bool nextUnread();

    /**
     * activates next new message.
     */
    void next();

protected:
    /** Reimplemented */
    virtual void mousePressEvent( QMouseEvent* );
    virtual void keyPressEvent( QKeyEvent* e );

signals:
    /**
     * emitted on  key left / right
     * @param item the item
     */
    void goActive( const QModelIndex& );

    /**
     * emitted on middle click
     * @param item the item
     */
    void selectMessageMiddle( const Akonadi::Item& item );

    /**
     * emitted on right click
     * @param item the item
     */
    void selectMessageRight( const Akonadi::Item& item );

    /**
     * Emitted when user presses a key which should be dealth with elsewhere
     */
    void actionRequested( MessageBodyWidget::KeyAction );

};

}

#endif
