/*
   Copyright (C) 2007 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/


#ifndef HEADERWIDGET_H
#define HEADERWIDGET_H

#include <QWidget>
#include <akonadi/item.h>
#include <akonadi/collection.h>

class QModelIndex;
class KJob;

namespace Akonadi
{
class MessageModel;
} // namespace Akonadi

namespace Mailody
{

class HeaderProxy;
class HeaderThreading;
class HeaderView;
class SearchLine;

/**
 * @class HeaderWidget
 * This is het main class for the header list.
 * @author Tom Albers <tomalbers@kde.nl>
 */
class HeaderWidget : public QWidget
{
    Q_OBJECT

public:
    /**
    * Contructor
    * @param parent The parent widget
    */
    explicit HeaderWidget( QWidget *parent );

    /**
    * Destructor
    */
    ~HeaderWidget();

    /** Returns the view */
    HeaderView *view()  {
        return m_headerView;
    };

    /** Returns the model */
    Akonadi::MessageModel *messageModel() {
        return m_messageModel;
    };

    /** Load the headers of a certain collection
     * @param id the id of the collection.
     */
    void setCollection( int id );

    /** Load the headers of a certain collection
     * @param collection the collection.
     */
    void setCollection( Akonadi::Collection collection );

    /** Sort on youngest child */
    void setSortOnChild( bool );

    /** Hide deleted messages? */
    void setHideDeleted( bool );

    /** Return a list of selected items */
    QList< Akonadi::Item > currentlySelectedItems();

public slots:
    void setSearch( const QString& );
    void itemActivated( const QModelIndex& );

// @cond private
private slots:
    void itemFetchDone( KJob* );

private:
    Akonadi::MessageModel *m_messageModel;
    Akonadi::Item   m_requestedItem;
    HeaderProxy     *m_headerProxy;
    HeaderThreading *m_headerThreading;
    HeaderView      *m_headerView;
    SearchLine      *m_searchLine;
// @endcond

signals:
    /** Emitted when a header is clicked with the left mouse */
    void selectMessageLeft( const Akonadi::Item& );
};

}

#endif // HEADERWIDGET
