/* This file is part of the KDE project
   Copyright (C) 2006 Omat Holding B.V. <info@omat.nl>
   Copyright (C) 2007 Frode M. Døving <frode@lnix.net>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include <stdio.h>
#include <stdlib.h>

#include <QDBusInterface>
#include <KStartupInfo>
#include <KDebug>
#include <KCmdLineArgs>
#include <KAboutData>
#include <KLocale>
#include <kontactinterface/pimuniqueapplication.h>

#include "aboutdata.h"
#include "mailodymain.h"
#include "mainwindow.h"

/**
 * @class MailodyApplication
 * @author Tom Albers <tomalbers@kde.nl>
 * This class is a simple inheritance from KUniqueApplication
 * the reason that it is reimplemented is so mailto's will work
 * even when mailody is already running.
 */
class MailodyApplication : public KontactInterface::PimUniqueApplication
{
public:
    /**
     * Similar to KUniqueApplication::newInstance, only without
     * the call to raise the widget when a second instance is started.
     */
    int newInstance() {
        KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
        if ( args ) {
            bool send = false;
            QString sComposeArgs;
            QString sAttachArgs;
            QString sSubjectArgs;
            QString sBodyArgs;

            if ( args->isSet( "compose" ) ) {
                const QStringList cArgLst = args->getOptionList( "compose" );
                if ( !cArgLst.empty() ) {
                    send = true;
                    for ( QStringList::ConstIterator ite = cArgLst.constBegin();
                            ite != cArgLst.constEnd();
                            ++ite )
                        if ( !( *ite ).isEmpty() )
                            sComposeArgs.append( *ite + ',' );
                }
                kDebug() << "sComposeArgs: " << sComposeArgs << endl;
            }

            if ( args->isSet( "attach" ) ) {
                const QStringList aArgLst = args->getOptionList( "attach" );
                if ( !aArgLst.isEmpty() ) {
                    send = true;
                    for ( QStringList::ConstIterator ite = aArgLst.constBegin();
                            ite != aArgLst.constEnd();
                            ++ite )
                        if ( !( *ite ).isEmpty() )
                            sAttachArgs.append( *ite + ";;" );
                }
                kDebug() << "sAttachArgs: " << sAttachArgs << endl;
            }

            if ( args->isSet( "subject" ) ) {
                sSubjectArgs = args->getOption( "subject" );
                send = true;
            }

            if ( args->isSet( "body" ) ) {
                sBodyArgs = args->getOption( "body" );
                send = true;
            }

            if ( send ) {
                QDBusInterface dbus( "net.mailody.mailody", "/mailody",
                                     "net.mailody.mainwindow" );
                dbus.call( "slotOpenComposer", sComposeArgs, sAttachArgs, sSubjectArgs, sBodyArgs );
            }

            for ( int i=0; i < args->count(); i++ ) {
                const QString ar = args->arg( i );
                kDebug() << "Found: " << ar << endl;
                if ( ar.startsWith( QLatin1String( "mailto:" ) )
                        || ar.contains( QLatin1String( "@" ) ) == 1 ) {
                    QDBusInterface dbus( "net.mailody.mailody", "/mailody",
                                         "net.mailody.mainwindow" );
                    dbus.call( "slotOpenComposer", ar );
                }
            }
        }
        return  KUniqueApplication::newInstance();;
    }
};

int main( int argc, char *argv[] )
{
    AboutData aboutData;
    KCmdLineArgs::init( argc, argv, &aboutData );

    KCmdLineOptions cmdline;
    cmdline.add( "compose <email>", ki18n( "Open a composer with <email> as recipient" ) );
    cmdline.add( "attach <file>", ki18n( "Open a composer with <file> attached" ) );
    cmdline.add( "subject <subject>", ki18n( "Open a composer with the subject <subject>" ) );
    cmdline.add( "body <body>", ki18n( "Open a composer with <body>" ) );
    KCmdLineArgs::addCmdLineOptions( cmdline );
    KCmdLineArgs::addStdCmdLineOptions();

    if ( !KUniqueApplication::start() ) {
        KStartupInfo::handleAutoAppStartedSending();
        fprintf( stderr, "Mailody is already running!\n" );
        exit( 0 );
    }

    MailodyApplication app;
    KGlobal::locale()->insertCatalog( "libakonadi" );
    Mailody::MailodyMain* mailody = new Mailody::MailodyMain();
    mailody->show();

    return app.exec();

}
