/* This file is part of the KDE project

   Copyright (C) 2006-2007 Omat Holding B.V. <info@omat.nl>
   Copyright (C) 2006-2007 Frode M. Døving <frode@lnix.net>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "headerwidget.h"
#include "nepomukwidget.h"
#include "messagebodywidget.h" //enum
#include <kxmlguiwindow.h>
#include <akonadi/item.h>
#include <akonadi/collection.h>
#include <akonadi/agentmanager.h>
#include <akonadi/entitytreemodel.h>

class KHBox;
class KSqueezedTextLabel;
class KToggleAction;
class KAction;
class KActionMenu;
class QSplitter;

namespace Akonadi
{
class CollectionView;
class EntityListView;
class CollectionModel;
}

using Akonadi::AgentManager;

namespace Akonadi
{
class EntityTreeView;
class FavoriteCollectionsView;
class Job;
class StandardActionManager;
class StatisticsToolTipProxyModel;
class Monitor;
}

namespace Mailody
{

class CollectionProxy;
class QuickReplyWidget;
class MessageData;
class ToolTip;
class SystemTray;
class TabWidget;


/**
 * @class MainWindow
 * This is one of the two main interfaces of Mailody. The class is pretty
 * crowded with methods, but mostly internal ones.
 * @author Tom Albers <tomalbers@kde.nl>
 */
class MainWindow : public QWidget
{
    Q_OBJECT
    Q_CLASSINFO( "D-Bus Interface", "net.mailody.mainwindow" )

public:
    /**
    * Contructor
    */
    MainWindow( KXmlGuiWindow*, KXMLGUIClient*, QWidget*, KActionCollection* );

    /**
     * Destructor
    */
    ~MainWindow();

protected:
    /** Reimplemented to see if there are dirty composer children. */
    void closeEvent( QCloseEvent* );

// @cond private
public Q_SLOTS:
    void slotNewMessage( const QString &to=QString() );
    void slotOpenComposer(
        const QString &address=QString(),
        const QString &files=QString(),
        const QString &subject=QString(),
        const QString &body=QString(),
        Akonadi::Collection mb=Akonadi::Collection()
    );
    void slotCheckMail();

    void slotSetup();
    void slotSortOnYoungestChild();
    void slotQuit();

    void slotHideDeleted();
    void slotToggleDelete();
    void slotToggleHTML();
    void slotQuickReply();
    void slotToggleSource();
    void slotToggleFixedFont();
    void slotToggleExternalImage();
    void slotUserFlag( int flag );

    void slotSave();
#ifdef WITHNEPOMUMPLAYGROUND
    void slotShowPossibleTags();
#endif
    void slotPrint();
    void slotZoomIn();
    void slotZoomOut();
    void slotScrollBottom();
    void slotNextUnread();

private:
    void createDocks();
    void createActions();
    void loadSettings();

    Akonadi::Collection findAnInbox();

    //they can go to headerwidget?, maybe that's a better place?
    void setTag( const Akonadi::Item& item, const QString& tag );
    void setTag( const QString& tag );
    void removeSingleTag( Akonadi::Item item, const QString& flag );
    void removeTag( const QString& tag );

    void startupSetup();
    void showMessage( const Akonadi::Item&, const Akonadi::Collection& );
    void setActionStates();
    void setStatusBarStates();
    void messageMenu( KActionMenu *am );

    KXmlGuiWindow                       *m_xmlGuiWindow;
    KXMLGUIClient                       *m_xmlGuiClient;
    KActionCollection                   *m_actionCollection;
    KStatusBar                          *m_statusBar;
    Akonadi::EntityTreeView             *m_collectionView;
    Akonadi::EntityListView             *m_favoritesView;
    Akonadi::Collection                 m_currentCollection;

    QSplitter                           *m_headerAndViewer;
    QSplitter                           *m_folderSplitter;
    KHBox                               *m_right;
    TabWidget                           *m_tabWidget;
    QuickReplyWidget                    *m_quickReplyWidget;
    NepomukWidget                       *m_nepomuk;

    HeaderWidget                        *m_headerWidget;

    ToolTip                             *m_tooltip;
    bool                                m_standAlone;

    // Tab Actions
    KAction                             *m_closeAction;
    KToggleAction                       *m_plainTextAction;
    KToggleAction                       *m_sourceAction;
    KToggleAction                       *m_fixedfontAction;
    KToggleAction                       *m_externalImageAction;

    // Mailody actions
    KAction                             *m_checkNowAction;
    KAction                             *m_syncResource;

    // Collection actions
    KAction                             *m_prevUnreadAction;
    KAction                             *m_nextUnreadAction;
    KAction                             *m_purgeAction;
    KAction                             *m_selectAllAction;
    //KToggleAction                       *m_childSortAction;
    KToggleAction                       *m_showDeletedAction;

    // Message actions
    KAction                             *m_msgNewAction;
    KActionMenu                         *m_msgNewActionMenu;
    KAction                             *m_msgZoomInAction;
    KAction                             *m_msgZoomOutAction;
    KAction                             *m_msgSaveAction;
    KAction                             *m_msgPrintAction;
#ifdef WITHNEPOMUMPLAYGROUND
    KAction                             *m_msgPossibleTagAction;
#endif
    KAction                             *m_msgReplyAction;
    KAction                             *m_msgForwardAction;
    KActionMenu                         *m_msgForwardActionMenu;
    KAction                             *m_msgReEditAction;
    KToggleAction                       *m_msgDelAction;
    KAction                             *m_msgUser0Action;
    KAction                             *m_msgUser1Action;
    KAction                             *m_msgUser2Action;
    KAction                             *m_msgUser3Action;
    KAction                             *m_msgUser4Action;
    KAction                             *m_msgUser5Action;
    KToggleAction                       *m_relatedAction;

    KAction                             *m_nepoAction;
    KAction                             *m_favAction;
    KToggleAction                       *m_favViewAction;
    KAction                             *m_mbAction;

    QDockWidget                         *m_favoriteDock;
    QDockWidget                         *m_mailboxDock;
    QDockWidget                         *m_nepoDock;

    SystemTray                          *m_systemTray;

    QString                             m_lastMessage;
    QTimer                              *m_statusTimer;

    QList<MessageData*>                 m_addheaderlist_val;

    bool                                m_online;
    KSqueezedTextLabel                  *m_statusText;
    QHash<MessageWidget*,MessageData*>  m_messageDataList;
    QHash<MessageWidget*,Akonadi::Item> m_itemList;

private slots:
    void slotChangeFavoritesView();
    void slotContextMenuHeaders( const Akonadi::Item& );

    void slotNotifications();
    void slotNewMessageMenu();
    void slotNewMessageMenuSelected( QAction* );
    void slotForwardMessage( const QString &to=QString() );
    void slotForwardMessageMenu();
    void slotForwardMessageMenuSelected( QAction* );
    void slotReEditMessage( const QString &to=QString() );
    void slotReplyMessage();
    void slotPurge();
    void slotSyncAllFolderLists();
    void slotInstanceAdded( const Akonadi::AgentInstance &instance );
    void slotSyncFolderList();

    void slotShowMessage( const Akonadi::Item& );
    void slotMiddleClickInHeaders( const Akonadi::Item& );

    void slotNewTab();
    void slotDeleteTab();
    void slotCurrentTabChanged( int );
    void slotUpdateTabTitle( const QString& );
    void slotTabAction( MessageBodyWidget::KeyAction );

    void slotSelectAllMessages();
    void slotOpenURLInNewTab( const QString& );

    void slotUpdateStatusBar( const QString& );
    void slotUpdateStatusBarRestoreMouse( const QString &text );
    void slotSimpleMessageStatusBar( const QString &text );
    void slotClearStatusBar();
    void slotStatusBarReady();
    void slotStatusBarClicked( int i );
    void collectionClicked( const Akonadi::Collection &collection );
    void slotAgentInstanceStatusChanged( const Akonadi::AgentInstance &instance );
    void slotAgentInstanceProgressChanged( const Akonadi::AgentInstance &instance );
    void slotResultStoreJob( KJob* );
    void slotEnablePossibleTagsAction( bool );
// @endcond

signals:
    /** Signal emitted when the user has been in the settings, this way you can reload
     * your settings if you want to */
    void setupFinished();
};

}


#endif
