/*
   Copyright (C) 2006-2007 Omat Holding B.V. <info@omat.nl>
   Copyright (C) 2007 Frode M. Døving <frode@lnix.net>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef MESSAGEHEADERWIDGET_H
#define MESSAGEHEADERWIDGET_H

#include "messagedata.h"
#include "messagewidget.h"

#include <QTextBrowser>

class QLabel;
class QGridLayout;

namespace Mailody
{

/**
 * @class MessageHeaderWidget
 * This class will show the headers.
 * part of the MessageWidget class.
 * @author Tom Albers <tomalbers@kde.nl>
 */
class MessageHeaderWidget : public QTextBrowser
{
    Q_OBJECT

public:
    /**
     * Constructor
     */
    explicit MessageHeaderWidget( MessageWidget* );

    /**
     * Destructor
     */
    ~MessageHeaderWidget();

    /**
     * this will fill the widget with the info from @p msg
     * you probably don't want to call this, you probably want
     * MessageWidget::setMsg() so it also updates the body
     * @param msg The message to show
     */
    void setMsg( MessageData* msg );

    /**
     * remove the existing info.
     */
    void clearView();

    /**
     * Reread config for the autosaving feature for attachments
     */
    void autoSaveAttachments();

// @cond private
private slots:
    void slotLeftMouseClick( const QUrl& );
    void slotRightMouseClick( const QPoint& );
    void updateHeaders();
// @endcond

signals:
    /**
     * Emitted when clicked on an address
     * @param email the emailaddress clicked on.
     */
    void openComposer( const QString &email );

// @cond private
private:
    void getFreeFilename( KUrl &fileLocation );
    void autoSaveAttachment( const KUrl&, const QString& );
    MessageData*                m_currentMessage;
    QGridLayout*                m_layout;
    QLabel*                     m_foto;
    bool                        m_storeAttachments;
    KUrl                        m_attachmentFolder;
    ContactTreeModel*           m_addressbookModel;
// @endcond
};

}
#endif
