/*

   Copyright (C) 2006-2007 Omat Holding B.V. <info@omat.nl>
   Copyright (C) 2007 Frode M. Døving <frode@lnix.net>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef MESSAGEVIEW_H
#define MESSAGEVIEW_H

#include <QWidget>
#include <QGridLayout>

#include <akonadi/collection.h>
#include <akonadi/item.h>

class QSplitter;
class QWebPage;

namespace Mailody
{

class ContactTreeModel;
class MessageData;
class MessageHeaderWidget;
class MessageBodyWidget;

/** @class MessageWidget
 * This class is responsible for displaying messages. It consits of three
 * classes. There is a MessageWidget, which displays two widgets: the MessageHeaderWidget
 * for all the headers and the MessageBodyWidget which contains the body of the
 * message
 * @author Tom Albers <tomalbers@kde.nl>
 */
class MessageWidget : public QWidget
{
    Q_OBJECT
public:
    /**
     * Constructor
     */
    explicit MessageWidget( QWidget* );

    /**
     * Destructor
     */
    ~MessageWidget();

    /**
     * returns a pointer to the header widget
     */
    MessageHeaderWidget*  headers() const     {
        return m_headers;
    };

    /**
     * returns a pointer to the body widgget
     */
    MessageBodyWidget* body() const        {
        return m_body;
    };

    /**
     * returns a pointer to the currently shown message, or 0.
     */
    MessageData* msg() const         {
        return m_msg;
    };

    /**
     * returns a pointer to the addressbook model
     */
    ContactTreeModel* addressbookModel() {
        return m_addressbookModel;
    }

    /**
     * this call asks to show @p msg in the view.
     */
    void setMsg( MessageData* );

    /**
     * this will hide the headers and clear the body.
     */
    void clearView();

    /**
     * guess what...
     */
    void print();

    /**
     * Guess again...
     */
    void save( const QString& );

    /**
     * Reread config for the autosaving feature for attachments
     */
    void autoSaveAttachments();

signals:
    void possibleTagsAvailable( bool );

// @cond private
private:
    MessageData             *m_msg;
    MessageHeaderWidget     *m_headers;
    MessageBodyWidget       *m_body;
    QWebPage                *m_printPart;
    ContactTreeModel        *m_addressbookModel;
    QSplitter               *m_splitter;

private slots:
    void slotPrintPreview();

// @endcond
};
}

#endif
