/*
   Copyright (C) 2008-2009 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "nepomukwidget.h"
#include "messagedata.h"

#include <QGridLayout>

#include <KDebug>
#include <KDialog>
#include <KVBox>
#include <QLabel>
#include <QCheckBox>

#include "nepomuk/kmetadatatagwidget.h"

using namespace Mailody;
using namespace Nepomuk;

NepomukWidget::NepomukWidget( QWidget* parent )
        : QWidget( parent )
{
    m_tags = new MetaDataWidget( this );
    m_tags->setHiddenData( MetaDataWidget::TypeData | MetaDataWidget::ModifiedData |
                           MetaDataWidget::SizeData | MetaDataWidget::OwnerData |
                           MetaDataWidget::PermissionsData | MetaDataWidget::RatingData );

    QGridLayout* layout = new QGridLayout( this );
    layout->setSpacing( 5 );
    layout->setMargin( 5 );
    layout->addWidget( m_tags, 0, 0 );
}

void NepomukWidget::setMsg( const KUrl& data )
{
    m_tags->setItem( data );
}

#ifdef WITHNEPOMUMPLAYGROUND
void NepomukWidget::showPossibleTagDialog( MessageData* data )
{
    kDebug();


    QList<Nepomuk::Annotation*> annotations = data->possibleAnnotations();
    if ( annotations.isEmpty() )
        return;

    KDialog *dialog = new KDialog( 0 );
    dialog->setCaption( "Possible tags for this e-mail" );
    dialog->setButtons( KDialog::Ok | KDialog::Cancel );
    KVBox* vbox = new KVBox( dialog );
    QLabel *widget = new QLabel( i18n( "These are possible tags for this e-mail:" ), vbox );
    QHash< QCheckBox*, QString > labelList;
    foreach( Nepomuk::Annotation *annotation, annotations ) {
        kDebug() << "Possible annotation found: " << annotation->label() << annotation->comment() << annotation->relevance();
        QCheckBox* box = new QCheckBox( annotation->label() + " (" + annotation->comment() + ')', vbox );
        labelList.insert( box, annotation->label() );
    }

    // see if after filtering out the existing tags, there is still something to do.
    if ( labelList.isEmpty() ) {
        delete dialog;
        return;
    }

    dialog->setMainWidget( vbox );
    if ( dialog->exec() == QDialog::Rejected ) {
        delete dialog;
        return;
    }

    Nepomuk::Resource res( data->item().url() );
    QHashIterator<QCheckBox*, QString> i( labelList );
    while ( i.hasNext() ) {
        i.next();
        if ( i.key()->checkState() == Qt::Checked ) {
            kDebug() << i.value();
            Nepomuk::Tag tag( i.value() );
            res.addTag( tag );
        }
    }
    delete dialog;
}
#endif

#include "nepomukwidget.moc"
