/*
    Copyright (c) 2009 Omat Holding B.V. <info@omat.nl>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#include "recentattributes.h"

#include <QByteArray>

#include <akonadi/attribute.h>

AmountAttribute::AmountAttribute() : m_amount( 0 )
{
}

void AmountAttribute::setAmount( int amount )
{
    m_amount = amount;
}

int AmountAttribute::amount() const
{
    return m_amount;
}

QByteArray AmountAttribute::type() const
{
    return "AMOUNT";
}

Akonadi::Attribute* AmountAttribute::clone() const
{
    AmountAttribute* attr = new AmountAttribute();
    attr->setAmount( amount() );
    return attr;
}

QByteArray AmountAttribute::serialized() const
{
    QByteArray ba;
    ba.setNum( m_amount );
    return ba;
}

void AmountAttribute::deserialize( const QByteArray &data )
{
    m_amount = data.toInt();
}


// -------------------------------------------------------------------------------


DateAttribute::DateAttribute() : m_date( QDateTime() )
{
}

void DateAttribute::setDate( QDateTime date )
{
    m_date = date;
}

QDateTime DateAttribute::date() const
{
    return m_date;
}

QByteArray DateAttribute::type() const
{
    return "RECENTDATE";
}

Akonadi::Attribute* DateAttribute::clone() const
{
    DateAttribute* attr = new DateAttribute();
    attr->setDate( date() );
    return attr;
}

QByteArray DateAttribute::serialized() const
{
    return m_date.toString( Qt::ISODate ).toLatin1();
}

void DateAttribute::deserialize( const QByteArray &data )
{
    m_date = QDateTime::fromString( data, Qt::ISODate );
}

