/*
   Copyright (C) 2009 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef RECENTMANAGER_H
#define RECENTMANAGER_H

#include <QObject>

#include <akonadi/collection.h>
#include <kjob.h>

namespace Mailody
{

class RecentManager : public QObject
{
    Q_OBJECT

public:
    RecentManager();

    /**
     * Returns an instance of Addressbook. Never create your own instance
     * of Addressbook, but use this method instead to get the one and only
     * instance.
     */
    static RecentManager *instance();

    /**
      * get the model for the recent address. If not exists, it will be
      * created. In the end it will emit recentCollection
      */
    void getRecentCollection();

    /**
      * Adds the address to the recent collection.
      */
    void add( const QString& address, const QString& name );

private slots:
    void slotRecentCollectionsReceived( Akonadi::Collection::List list );
    void slotRecentResourceCreated( KJob *job );

signals:
    void recentCollection( Akonadi::Collection );

private:
    void getCollectionFromRecentResource( const QString& identifier );
    static RecentManager* m_instance;
    Akonadi::Collection m_collection;
};

}

#endif // RECENTMANAGER_H
