/*
   Copyright (C) 2006-2009 Omat Holding B.V. <info@omat.nl>
   Copyright (C) 2007 Frode M. Døving <frode@lnix.net>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef RECIPIENTWIDGET_H
#define RECIPIENTWIDGET_H

#include <QWidget>

class QAbstractItemModel;
class QPushButton;
class QTreeWidgetItem;

namespace Mailody
{

class AddressLineEdit;
class ComposerRecipientWidget;

class RecipientWidget : public QWidget
{
    Q_OBJECT

public:
    /**
     * You can use this enum for setRcpt, to set the type
     */
    enum TypeOfAddress {
        To = 1,
        Cc,
        Bcc
    };


    RecipientWidget( QWidget* parent, QAbstractItemModel* completionModel );

    /**
     * Adds an address to the composer
     * @param address address to add
     * @param addressType the type of address
     */
    void setRcpt( const QString& address,
                  TypeOfAddress addressType );

    /**
     * Retrieves the list of recipients listed for an addressType
     */
    QStringList list( TypeOfAddress addressType ) const;

    /**
     * True if there is one or more recipients.
     */
    bool hasRecipients() const;

public slots:
    /** Adds an address, */
    void slotAddAddress( const QString& );

signals:
    void dirty();

private slots:
    void slotContainsValidAddress( bool active );
    void slotUpdateLineEdit();
    void slotEditAddress( QTreeWidgetItem* lvi, int c );
    void slotShiftAddress();
    void slotAddClicked();
    void slotSetAddress( const QString& address );


private:
    QPushButton*                    m_add;
    AddressLineEdit                 *m_edit;
    ComposerRecipientWidget         *m_addressbox;
    int                             m_lastState;
    QTreeWidgetItem                 *m_lastInserted;

};

}
#endif // RECIPIENTWIDGET_H
