/* This file is part of the KDE project

   Copyright (C) 2008 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "tabwidget.h"
#include "messagewidget.h"

#include <KConfigGroup>
#include <KDebug>
#include <KIcon>

#include <QMenu>
#include <QToolButton>

using namespace Mailody;

TabWidget::TabWidget( QWidget *parent )
        : QTabWidget( parent )
{
    setTabPosition( QTabWidget::North );
    setMovable( true );
    setTabsClosable( false ); // not the first (and only) one.
    connect( this, SIGNAL( tabCloseRequested( int ) ),
             SLOT( slotDeleteTab( int ) ) );

    QToolButton *button = new QToolButton( this );
    button->setIcon( KIcon( "tab-new" ) );
    button->adjustSize();
    setCornerWidget( button, Qt::TopLeftCorner );
    connect( button, SIGNAL( clicked() ), SIGNAL( clicked() ) );

    m_closeButton = new QToolButton( this );
    m_closeButton->setIcon( KIcon( "tab-close" ) );
    m_closeButton->adjustSize();
    m_closeButton->setEnabled( false );
    setCornerWidget( m_closeButton, Qt::TopRightCorner );
    connect( m_closeButton, SIGNAL( clicked() ), SLOT( slotDeleteCurrentWidget() ) );
}

void TabWidget::addMessageTab( MessageWidget *widget, const QString &text )
{
    addTab( widget, text, Message );
}

void TabWidget::addBrowserTab( MessageWidget *widget, const QString &text )
{
    addTab( widget, text, Browser );
}

void TabWidget::addTab( QWidget *widget, const QString &text, Type type )
{
    const int index = QTabWidget::addTab( widget, text );
    setCurrentIndex( index );
    m_tabTypes.insert( index, type );

    if ( count() > 1 ) {
        m_closeButton->setEnabled( true );
        setTabsClosable( true );
    }
}

void TabWidget::slotDeleteCurrentWidget()
{
    slotDeleteWidget( currentWidget() );
}

void TabWidget::slotDeleteWidget( QWidget *widget )
{
    const int id = indexOf( widget );
    slotDeleteTab( id );
}

void TabWidget::slotDeleteTab( int id )
{
    m_tabTypes.remove( id );

    blockSignals( true );
    if ( count() != 1 )
        delete widget( id );
    blockSignals( false );

    if ( count() == 1 ) {
        m_closeButton->setEnabled( false );
        setTabsClosable( false );
    }
}

bool TabWidget::isCurrentTab( Type widgetType ) const
{
    const int id = currentIndex();
    return m_tabTypes.value( id ) == widgetType;
}

void TabWidget::setCurrentTabType( Type widgetType )
{
    m_tabTypes[ currentIndex()] = widgetType;
}

MessageWidget* TabWidget::tabWidget( int i ) const
{
    return static_cast<MessageWidget*>( widget( i ) );
}

MessageWidget* TabWidget::currentTabWidget() const
{
    return static_cast<MessageWidget*>( currentWidget() );
}

#include "tabwidget.moc"
