/* This file is part of the KDE project

   Copyright (C) 2008 Omat Holding B.V. <info@omat.nl>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#ifndef TABWIDGET_H
#define TABWIDGET_H

#include <QTabWidget>
#include <QHash>

class QToolButton;
class KAction;

namespace Mailody
{
class MessageWidget;

/**
 * @class TabWidget
 * @author Tom Albers <tomalbers@kde.nl>
 *  This class is a KTabWidget which can hold tabs for Messages and a browser screen.
 *  You can request the type with currentTabType().
 *
 *  Be carefull only to create the tabs with addMessageTab() or with addBrowserTab().
 *  Also only delete the tabs with the slotDeleteCurrentWidget() or slotDeleteWidget() calls.
 *  Doing it on your own will mess up the results when querying for the Type.
 */
class TabWidget : public QTabWidget
{
    Q_OBJECT

public:
    /** Indicates the type of a tab, either a Browser or a Messge */
    enum Type {
        Browser = 0,
        Message
    };

    /** Constructor
     * @param parent The parent Widget **/
    explicit TabWidget( QWidget *parent = 0 );

    /** Adds a message tab with a title */
    void addMessageTab( MessageWidget*, const QString& );

    /** Adds a browser tab with a title */
    void addBrowserTab( MessageWidget*, const QString& );

    /** Returns the widget for a tab */
    MessageWidget *tabWidget( int ) const;

    /** Returns the current widget */
    MessageWidget *currentTabWidget() const;

    /** Returns if the current tab is the one of the indicated type */
    bool isCurrentTab( Type ) const;

    /** Switches the current tab to the indicated type */
    void setCurrentTabType( Type );

public slots:
    /** Delete the current widget */
    void slotDeleteCurrentWidget();

    /** Delete widget */
    void slotDeleteWidget( QWidget* );

    /** Delete a certain tab */
    void slotDeleteTab( int );

// @cond private
private:
    void addTab( QWidget*, const QString&, Type );
    QToolButton *m_closeButton;
    KAction *m_closeAction;
    QHash<int, Type> m_tabTypes;
// @endcond

signals:
    /** Emitted when the new tab button is clicked */
    void clicked();
};

}

#endif
